@@ -273,6 +273,7 @@
 ;; procedure (typically calling Guile's @code{pointer->procedure}).
 ;; @* psize is proxy size (usually void* mtype).  Think of the proxy as a
 ;; trampoline for the function.  The pointer points to proxy (trampoline)
+;; @* This may need another field to enable correct @code{ctype-equal?}.
 ;; @end deftp
 (define-record-type <cfunction>
   (%make-cfunction proc->ptr ptr->proc variadic? ptr-mtype)
@@ -724,7 +725,9 @@
 ;; size, integer versus float, and signed versus unsigned.
 ;; For struct and union kinds, the names and types of all fields
 ;; must be equal.
-;; @*TODO: algorithm to prevent infinite search for recursive structs
+;; @* WARNING: Currently equality of pointers uses @code{eq?} (with
+;; forced promises).  Fixme is to create algorithm to chase down pointers
+;; without infinite search.
 ;; @end deffn
 (define (ctype-equal? a b)
   "- Procedure: ctype-equal? a b
@@ -756,7 +759,21 @@
                 ((and (promise? at) (promise? bt)) (eq? (force at) (force bt)))
                 ((promise? at) (eq? (force at) bt))
                 ((promise? bt) (eq? at (force bt)))
-                ((eq? at bt)))))
+                ((eq? at bt))
+                (else #f))))
+            ((array)
+             (and (eqv? (carray-length a) (carray-length b))
+                  (ctype-equal? (carray-type a) (carray-type b))))
+            ((enum)
+             (and (eq? (cenum-mtype a) (cenum-mtype b))
+                  (equal? (cenum-symd a) (cenum-symd b))))
+            ((function)
+             (and
+              (eq? (cfunction-variadic? a) (cfunction-variadic? b))
+              (eq? (cfunction-ptr-mtype a) (cfunction-ptr-mtype b))
+              (eq? (cfunction-proc->ptr a) (cfunction-proc->ptr b))
+              ;; HARD TO DO
+              #t))
             (else #f)))))
     (cond
      ((or (not (ctype? a)) (not (ctype? b))) #f)
